import datetime as dt
import logging

from fastapi import APIRouter
from pydantic import BaseModel

from webcontrol.detection import set_camera_detection, reset_all_cameras_detection_after_sunset
from webcontrol.utils.asyncio import create_task, schedule_coroutine

logger = logging.getLogger(__name__)

api = APIRouter()


@api.on_event("startup")
def schedule_reset_all_cameras_detection_after_sunset() -> None:
    create_task(reset_all_cameras_detection_after_sunset())


class TemporaryDetectionSettings(BaseModel):
    detection: bool = True
    duration: int = 0


@api.post("/camera/{camera}/detection")
async def post_camera_detection(camera: str, temporary_detection_settings: TemporaryDetectionSettings) -> dict[str, str]:
    await set_camera_detection(camera, temporary_detection_settings.detection)
    if temporary_detection_settings.duration > 0:
        schedule_coroutine(
            set_camera_detection(camera, not temporary_detection_settings.detection),
            dt.timedelta(minutes=temporary_detection_settings.duration)
        )

    return {
        "status": "success"
    }
